| Name                      | Version     | License                                                 | Author                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            | URL                                                                           |
|---------------------------|-------------|---------------------------------------------------------| |-------------------------------------------------------------------------------|
| Flask                     | 3.1.2       | BSD-3-Clause                                            | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://github.com/pallets/flask/                                             |
| ImageIO                   | 2.37.2      | BSD-2-Clause                                            | ImageIO contributors                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              | https://github.com/imageio/imageio                                            |
| Jinja2                    | 3.1.6       | BSD License                                             | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://github.com/pallets/jinja/                                             |
| Markdown                  | 3.10        | BSD-3-Clause                                            | Manfred Stienstra, Yuri Takhteyev                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 | https://Python-Markdown.github.io/                                            |
| MarkupSafe                | 3.0.3       | BSD-3-Clause                                            | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://github.com/pallets/markupsafe/                                        |
| PyYAML                    | 6.0.3       | MIT License                                             | Kirill Simonov                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | https://pyyaml.org/                                                           |
| Werkzeug                  | 3.1.3       | BSD License                                             | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | UNKNOWN                                                                       |
| absl-py                   | 2.3.1       | Apache-2.0                                              | The Abseil Authors                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | https://github.com/abseil/abseil-py                                           |
| aiobotocore               | 2.25.2      | Apache-2.0                                              | Nikolay Novik <nickolainovik@gmail.com>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://github.com/aio-libs/aiobotocore                                       |
| aiohappyeyeballs          | 2.6.1       | Python Software Foundation License                      | J. Nick Koston                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | https://github.com/aio-libs/aiohappyeyeballs                                  |
| aiohttp                   | 3.13.2      | Apache-2.0 AND MIT                                      | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://github.com/aio-libs/aiohttp                                           |
| aioitertools              | 0.13.0      | MIT                                                     | Amethyst Reese <amethyst@n7.gg>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   | https://aioitertools.omnilib.dev/en/latest/changelog.html                     |
| aiosignal                 | 1.4.0       | Apache Software License                                 | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://github.com/aio-libs/aiosignal                                         |
| annotated-types           | 0.7.0       | MIT License                                             | Adrian Garcia Badaracco <1755071+adriangb@users.noreply.github.com>, Samuel Colvin <s@muelcolvin.com>, Zac Hatfield-Dodds <zac@zhd.dev>                                                                                                                                                                                                                                                                                                                                                                                           | https://github.com/annotated-types/annotated-types                            |
| attrs                     | 25.4.0      | MIT                                                     | Hynek Schlawack <hs@ox.cx>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        | https://www.attrs.org/en/stable/changelog.html                                |
| bioio                     | 3.0.0       | BSD License                                             | Eva Maxfield Brown <evamaxfieldbrown@gmail.com>, Dan Toloudis <danielt@alleninstitute.org>                                                                                                                                                                                                                                                                                                                                                                                                                                        | https://github.com/bioio-devs/bioio                                           |
| bioio-base                | 3.0.0       | BSD License                                             | Eva Maxfield Brown <evamaxfieldbrown@gmail.com>, Dan Toloudis <danielt@alleninstitute.org>                                                                                                                                                                                                                                                                                                                                                                                                                                        | https://github.com/bioio-devs/bioio-base                                      |
| bioio-imageio             | 1.3.0       | MIT License                                             | Sean Meharry <seanm@alleninstitute.org>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://github.com/bioio-devs/bioio-imageio                                   |
| bioio-ome-tiff            | 1.4.0       | MIT License                                             | bioio-devs <brian.whitney@alleninstitute.org>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     | https://github.com/bioio-devs/bioio-ome-tiff                                  |
| bioio-ome-zarr            | 2.3.0       | MIT License                                             | bioio-devs <brian.whitney@alleninstitute.org>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     | https://github.com/BrianWhitneyAI/bioio-ome-zarr                              |
| bioio-tifffile            | 1.3.0       | MIT License                                             | Eva Maxfield Brown <evamaxfieldbrown@gmail.com>, Sean Meharry <seanm@alleninstitute.org>                                                                                                                                                                                                                                                                                                                                                                                                                                          | https://github.com/bioio-devs/bioio-tifffile                                  |
| blinker                   | 1.9.0       | MIT License                                             | Jason Kirtland                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | https://github.com/pallets-eco/blinker/                                       |
| botocore                  | 1.40.70     | Apache-2.0                                              | Amazon Web Services                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | https://github.com/boto/botocore                                              |
| certifi                   | 2025.11.12  | Mozilla Public License 2.0 (MPL 2.0)                    | Kenneth Reitz                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     | https://github.com/certifi/python-certifi                                     |
| charset-normalizer        | 3.4.4       | MIT                                                     | "Ahmed R. TAHRI" <tahri.ahmed@proton.me>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          | https://github.com/jawah/charset_normalizer/blob/master/CHANGELOG.md          |
| click                     | 8.3.0       | BSD-3-Clause                                            | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://github.com/pallets/click/                                             |
| cloudpickle               | 3.1.2       | BSD License                                             | The cloudpickle developer team                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | https://github.com/cloudpipe/cloudpickle                                      |
| contourpy                 | 1.3.3       | BSD License                                             | Ian Thomas <ianthomas23@gmail.com>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | https://github.com/contourpy/contourpy                                        |
| crc32c                    | 2.8         | GNU Lesser General Public License v2 or later (LGPLv2+) | Rodrigo Tobar <rtobar@icrar.org>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  | https://github.com/ICRAR/crc32c/blob/master/CHANGELOG.md                      |
| cycler                    | 0.12.1      | BSD License                                             | Thomas A Caswell <matplotlib-users@python.org>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | https://matplotlib.org/cycler/                                                |
| dash                      | 3.3.0       | MIT License                                             | Chris Parmer                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      | https://plotly.com/dash                                                       |
| dash-bootstrap-components | 2.0.4       | Apache Software License                                 | Faculty Science Ltd, Pascal Bugnion                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | https://www.dash-bootstrap-components.com/                                    |
| dash_ag_grid              | 32.3.2      | MIT License                                             | Plotly <chris@plot.ly>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            | https://dash.plotly.com/dash-ag-grid                                          |
| dask                      | 2025.11.0   | BSD-3-Clause                                            | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://github.com/dask/dask/                                                 |
| distributed               | 2025.11.0   | BSD License                                             | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://distributed.dask.org                                                  |
| donfig                    | 0.8.1.post1 | MIT License                                             | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://github.com/pytroll/donfig                                             |
| elementpath               | 5.0.4       | MIT                                                     | Davide Brunato <brunato@sissa.it>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 | https://github.com/sissaschool/elementpath                                    |
| fonttools                 | 4.60.1      | MIT                                                     | Just van Rossum                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   | http://github.com/fonttools/fonttools                                         |
| frozenlist                | 1.8.0       | Apache-2.0                                              | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://github.com/aio-libs/frozenlist                                        |
| fsspec                    | 2025.10.0   | BSD-3-Clause                                            | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://github.com/fsspec/filesystem_spec                                     |
| grpcio                    | 1.76.0      | Apache Software License                                 | The gRPC Authors                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  | https://grpc.io                                                               |
| idna                      | 3.11        | BSD-3-Clause                                            | Kim Davies <kim+pypi@gumleaf.org>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 | https://github.com/kjd/idna                                                   |
| imagecodecs               | 2025.11.11  | BSD-3-Clause                                            | Christoph Gohlke                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  | https://www.cgohlke.com                                                       |
| imageio-ffmpeg            | 0.6.0       | BSD License                                             | imageio contributors                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              | https://github.com/imageio/imageio-ffmpeg                                     |
| importlib_metadata        | 8.7.0       | Apache Software License                                 | "Jason R. Coombs" <jaraco@jaraco.com>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | https://github.com/python/importlib_metadata                                  |
| itsdangerous              | 2.2.0       | BSD License                                             | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://github.com/pallets/itsdangerous/                                      |
| jmespath                  | 1.0.1       | MIT License                                             | James Saryerwinnie                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | https://github.com/jmespath/jmespath.py                                       |
| kerchunk                  | 0.2.9       | MIT License                                             | Martin Durant <martin.durant@alumni.utoronto.ca>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  | UNKNOWN                                                                       |
| kiwisolver                | 1.4.9       | BSD License                                             | The Nucleic Development Team <sccolbert@gmail.com>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | https://github.com/nucleic/kiwi                                               |
| lazy_loader               | 0.4         | BSD License                                             | Scientific Python Developers                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      | https://github.com/scientific-python/lazy_loader                              |
| locket                    | 1.0.0       | BSD License                                             | Michael Williamson                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | http://github.com/mwilliamson/locket.py                                       |
| lxml                      | 6.0.2       | BSD-3-Clause                                            | lxml dev team                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     | https://lxml.de/                                                              |
| matplotlib                | 3.10.7      | Python Software Foundation License                      | John D. Hunter, Michael Droettboom                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | https://matplotlib.org                                                        |
| msgpack                   | 1.1.2       | Apache-2.0                                              | Inada Naoki <songofacandy@gmail.com>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              | https://msgpack.org/                                                          |
| multidict                 | 6.7.0       | Apache License 2.0                                      | Andrew Svetlov                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | https://github.com/aio-libs/multidict                                         |
| narwhals                  | 2.11.0      | MIT License                                             | Marco Gorelli <hello_narwhals@proton.me>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          | https://github.com/narwhals-dev/narwhals                                      |
| nest-asyncio              | 1.6.0       | BSD License                                             | Ewald R. de Wit                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   | https://github.com/erdewit/nest_asyncio                                       |
| networkx                  | 3.5         | BSD License                                             | Aric Hagberg <hagberg@lanl.gov>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   | https://networkx.org/                                                         |
| numcodecs                 | 0.16.3      | MIT                                                     | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://github.com/zarr-developers/numcodecs                                  |
| numpy                     | 2.2.6       | BSD License                                             | Travis E. Oliphant et al.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         | https://numpy.org                                                             |
| ome-types                 | 0.6.2       | MIT License                                             | Talley Lambert <talley.lambert@gmail.com>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         | https://github.com/tlambert03/ome-types                                       |
| opencv-python-headless    | 4.12.0.88   | Apache Software License                                 | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://github.com/opencv/opencv-python                                       |
| packaging                 | 25.0        | Apache Software License; BSD License                    | Donald Stufft <donald@stufft.io>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  | https://github.com/pypa/packaging                                             |
| pandas                    | 2.3.3       | BSD License                                             | The Pandas Development Team <pandas-dev@python.org>                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | https://pandas.pydata.org                                                     |
| partd                     | 1.4.2       | BSD                                                     | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | http://github.com/dask/partd/                                                 |
| patsy                     | 1.0.2       | BSD License                                             | Nathaniel J. Smith                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | https://github.com/pydata/patsy                                               |
| pillow                    | 12.0.0      | MIT-CMU                                                 | "Jeffrey A. Clark" <aclark@aclark.net>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            | https://python-pillow.github.io                                               |
| pixel-patrol              | 0.3.2       | UNKNOWN                                                 | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | UNKNOWN                                                                       |
| pixel-patrol-base         | 0.1.2       | UNKNOWN                                                 | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | UNKNOWN                                                                       |
| pixel-patrol-image        | 0.1.2       | UNKNOWN                                                 | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | UNKNOWN                                                                       |
| pixel-patrol-loader-bio   | 0.1.2       | UNKNOWN                                                 | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | UNKNOWN                                                                       |
| plotly                    | 6.4.0       | MIT License                                             | Chris P <chris@plot.ly>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://plotly.com/python/                                                    |
| polars                    | 1.35.2      | MIT License                                             | Ritchie Vink <ritchie46@gmail.com>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | https://www.pola.rs/                                                          |
| polars-runtime-32         | 1.35.2      | MIT License                                             | Ritchie Vink <ritchie46@gmail.com>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | https://www.pola.rs/                                                          |
| propcache                 | 0.4.1       | Apache Software License                                 | Andrew Svetlov                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | https://github.com/aio-libs/propcache                                         |
| protobuf                  | 6.33.0      | 3-Clause BSD License                                    | protobuf@googlegroups.com                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         | https://developers.google.com/protocol-buffers/                               |
| psutil                    | 7.1.3       | BSD-3-Clause                                            | Giampaolo Rodola                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  | https://github.com/giampaolo/psutil                                           |
| pyarrow                   | 22.0.0      | Apache Software License                                 | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://arrow.apache.org/                                                     |
| pydantic                  | 2.12.4      | MIT                                                     | Samuel Colvin <s@muelcolvin.com>, Eric Jolibois <em.jolibois@gmail.com>, Hasan Ramezani <hasan.r67@gmail.com>, Adrian Garcia Badaracco <1755071+adriangb@users.noreply.github.com>, Terrence Dorsey <terry@pydantic.dev>, David Montague <david@pydantic.dev>, Serge Matveenko <lig@countzero.co>, Marcelo Trylesinski <marcelotryle@gmail.com>, Sydney Runkle <sydneymarierunkle@gmail.com>, David Hewitt <mail@davidhewitt.io>, Alex Hall <alex.mojaki@gmail.com>, Victorien Plot <contact@vctrn.dev>, Douwe Maan <hi@douwe.me> | https://github.com/pydantic/pydantic                                          |
| pydantic-extra-types      | 2.10.6      | MIT                                                     | Samuel Colvin <s@muelcolvin.com>, Yasser Tahiri <hello@yezz.me>                                                                                                                                                                                                                                                                                                                                                                                                                                                                   | https://github.com/pydantic/pydantic-extra-types                              |
| pydantic_core             | 2.41.5      | MIT                                                     | Samuel Colvin <s@muelcolvin.com>, Adrian Garcia Badaracco <1755071+adriangb@users.noreply.github.com>, David Montague <david@pydantic.dev>, David Hewitt <mail@davidhewitt.dev>, Sydney Runkle <sydneymarierunkle@gmail.com>, Victorien Plot <contact@vctrn.dev>                                                                                                                                                                                                                                                                  | https://github.com/pydantic/pydantic-core                                     |
| pyparsing                 | 3.2.5       | MIT                                                     | Paul McGuire <ptmcg.gm+pyparsing@gmail.com>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       | https://github.com/pyparsing/pyparsing/                                       |
| python-dateutil           | 2.9.0.post0 | Apache Software License; BSD License                    | Gustavo Niemeyer                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  | https://github.com/dateutil/dateutil                                          |
| pytz                      | 2025.2      | MIT License                                             | Stuart Bishop                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     | http://pythonhosted.org/pytz                                                  |
| requests                  | 2.32.5      | Apache Software License                                 | Kenneth Reitz                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     | https://requests.readthedocs.io                                               |
| retrying                  | 1.4.2       | Apache-2.0                                              | Alex Kuang, Anthony McClosky, Cyrus Durgin, Daniel Nephin, Dougal Matthews, Greg Roodt, Haïkel Guémar, Hugo Klepsch, J Derek Wilson, James Page, Jason Dunkelberger, Job Evers, Jonathan Herriott, Josh Marshall, Joshua Harlow, Justin Turner Arthur, Maxym Shalenyi, Monty Taylor, Pierre-Yves Chibon, Ray Holder, Rees Dooley, Saul Shanabrook, Simon Dollé, Simeon Visser, Thomas Goirand                                                                                                                                     | https://github.com/groodt/retrying                                            |
| s3fs                      | 2025.10.0   | BSD License                                             | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | http://github.com/fsspec/s3fs/                                                |
| scikit-image              | 0.25.2      | BSD License                                             | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://scikit-image.org                                                      |
| scipy                     | 1.16.3      | BSD License                                             | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://scipy.org/                                                            |
| semver                    | 3.0.4       | BSD License                                             | Kostiantyn Rybnikov <k-bx@k-bx.com>, Tom Schraitle <toms@suse.de>                                                                                                                                                                                                                                                                                                                                                                                                                                                                 | https://python-semver.readthedocs.io/en/latest/changelog.html                 |
| six                       | 1.17.0      | MIT License                                             | Benjamin Peterson                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 | https://github.com/benjaminp/six                                              |
| sortedcontainers          | 2.4.0       | Apache Software License                                 | Grant Jenks                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       | http://www.grantjenks.com/docs/sortedcontainers/                              |
| statsmodels               | 0.14.5      | BSD License                                             | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://www.statsmodels.org/                                                  |
| tblib                     | 3.2.2       | BSD-2-Clause                                            | Ionel Cristian Mărieș <contact@ionelmc.ro>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        | https://python-tblib.readthedocs.io/en/latest/changelog.html                  |
| tensorboard               | 2.20.0      | Apache Software License                                 | Google Inc.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       | https://github.com/tensorflow/tensorboard                                     |
| tensorboard-data-server   | 0.7.2       | Apache Software License                                 | Google Inc.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       | https://github.com/tensorflow/tensorboard/tree/master/tensorboard/data/server |
| tensorboardX              | 2.6.4       | MIT                                                     | Tzu-Wei Huang <huang.dexter@gmail.com>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            | https://github.com/lanpa/tensorboardX                                         |
| tifffile                  | 2025.9.9    | BSD-3-Clause                                            | Christoph Gohlke                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  | https://www.cgohlke.com                                                       |
| toolz                     | 1.1.0       | BSD-3-Clause                                            | PyToolz Contributors                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              | https://github.com/pytoolz/toolz                                              |
| tornado                   | 6.5.2       | Apache Software License                                 | Facebook                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          | http://www.tornadoweb.org/                                                    |
| tqdm                      | 4.67.1      | MIT License; Mozilla Public License 2.0 (MPL 2.0)       | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | https://tqdm.github.io                                                        |
| typing-inspection         | 0.4.2       | MIT                                                     | Victorien Plot <contact@vctrn.dev>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | https://github.com/pydantic/typing-inspection                                 |
| typing_extensions         | 4.15.0      | PSF-2.0                                                 | "Guido van Rossum, Jukka Lehtosalo, Łukasz Langa, Michael Lee" <levkivskyi@gmail.com>                                                                                                                                                                                                                                                                                                                                                                                                                                             | https://github.com/python/typing_extensions                                   |
| tzdata                    | 2025.2      | Apache Software License                                 | Python Software Foundation                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        | https://github.com/python/tzdata                                              |
| ujson                     | 5.11.0      | UNKNOWN                                                 | Jonas Tarnstrom                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   | https://github.com/ultrajson/ultrajson                                        |
| urllib3                   | 2.5.0       | MIT                                                     | Andrey Petrov <andrey.petrov@shazow.net>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          | https://github.com/urllib3/urllib3/blob/main/CHANGES.rst                      |
| wrapt                     | 1.17.3      | BSD License                                             | Graham Dumpleton                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  | https://github.com/GrahamDumpleton/wrapt                                      |
| xarray                    | 2025.10.1   | Apache-2.0                                              | xarray Developers <xarray@googlegroups.com>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       | https://xarray.dev/                                                           |
| xmlschema                 | 4.2.0       | MIT                                                     | Davide Brunato <brunato@sissa.it>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 | https://github.com/sissaschool/xmlschema                                      |
| xsdata                    | 25.7        | MIT License                                             | Christodoulos Tsoulloftas <chris@komposta.net>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | https://github.com/tefra/xsdata                                               |
| yarl                      | 1.22.0      | Apache Software License                                 | Andrew Svetlov                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | https://github.com/aio-libs/yarl                                              |
| zarr                      | 3.1.1       | MIT                                                     | Alistair Miles <alimanfoo@googlemail.com>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         | https://github.com/zarr-developers/zarr-python                                |
| zict                      | 3.0.0       | BSD License                                             | UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           | http://zict.readthedocs.io/en/latest/                                         |
| zipp                      | 3.23.0      | MIT                                                     | "Jason R. Coombs" <jaraco@jaraco.com>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             | https://github.com/jaraco/zipp                                                |
